/***************************************************************************
                          ksnes9xoptionsdialog.cpp  -  description
                             -------------------
    begin                : Sun Oct 24 1999
    copyright            : (C) 1999 by Perdig
    email                : perdig@linuxbr.com.br
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ksnes9xoptionsdialog.h"

extern QString FILTER;
extern QString PATH;
extern QString SNAP_FILTER;
extern QString SNAP_PATH;
extern QString SNES9X;
extern bool QUICK_SNAP;
extern bool QUICK_PROF;

KSnes9xOptionsDialog::KSnes9xOptionsDialog(QWidget *parent, const char *name)
	:QTabDialog( parent, name, true )
{

	this->setFixedSize(475, 365);

	/* Widgets */
	main_page = new QWidget(this, "Main Page");
	quick_page = new QWidget(this, "Quick Page");

	/* Snes9x Box */

	// Initialize
	snes9x_box = new QGroupBox(i18n("Snes9x"), main_page);
	snes9x_label = new QLabel(i18n("Snes9x path:"), snes9x_box);
	snes9x_path = new KLined(snes9x_box);
	snes9x_browse = new QPushButton(snes9x_box);

	// Geometry
	snes9x_box->setGeometry( 5, 5, 450, 60);
	snes9x_label->setGeometry( 5, 17, 125, 30 );
	snes9x_path->setGeometry( 135, 17, 275, 30 );
	snes9x_browse->setGeometry( 415, 17, 30, 30 );

	// Configure and connect
	snes9x_browse->setPixmap( Icon("open.xpm") );
	snes9x_path->setText( SNES9X );
	connect( snes9x_browse, SIGNAL(clicked()), this, SLOT(snes9x_click()) );
	

	/* Rom box */

	// Initialize
	rom_box = new QGroupBox(i18n("ROM"), main_page);
	rom_filter = new KLined( rom_box );
	rom_label_filter = new QLabel( i18n("ROM filter:"), rom_box );
	rom_label_path = new QLabel( i18n("ROM path:"), rom_box );
	rom_path = new KLined( rom_box );
	rom_path_browse = new QPushButton( rom_box );

	// Geometry
	rom_box->setGeometry( 5, 75, 450, 100 );
	rom_label_path->setGeometry( 5, 17, 125, 30 );
	rom_path->setGeometry( 135, 17, 275, 30 );
	rom_path_browse->setGeometry( 415, 17, 30, 30 );
	rom_label_filter->setGeometry( 5, 56, 125, 30 );
	rom_filter->setGeometry( 135, 56, 310, 30 );

	// Configure and connect
	rom_path_browse->setPixmap( Icon("open.xpm") );
	rom_path->setText( PATH );
	rom_filter->setText( FILTER );
	connect( rom_path_browse, SIGNAL(clicked()), this, SLOT(rom_path_click()) );


	/* Snapshot box */

	// Initialize
	snap_box = new QGroupBox(i18n("Snapshots"), main_page);
	snap_filter = new KLined(snap_box);
	snap_label_filter = new QLabel(i18n("Snapshots filter:"), snap_box);
	snap_label_path = new QLabel(i18n("Snapshots path:"), snap_box);
	snap_path = new KLined(snap_box);
	snap_path_browse = new QPushButton(snap_box);

	// Geometry
	snap_box->setGeometry(5, 185, 450, 100);
	snap_label_path->setGeometry( 5, 17, 125, 30 );
	snap_path->setGeometry( 135, 17, 275, 30 );
	snap_path_browse->setGeometry( 415, 17, 30, 30 );
	snap_label_filter->setGeometry( 5, 56, 125, 30 );
	snap_filter->setGeometry( 135, 56, 310, 30 );

	// Configure and connect
	snap_path->setText( SNAP_PATH );
	snap_filter->setText( SNAP_FILTER );
	snap_path_browse->setPixmap( Icon("open.xpm") );
	connect( snap_path_browse, SIGNAL(clicked()), this, SLOT(snap_path_click()) );

	/* Quick Loading page */

	// Box
	quick_box = new QGroupBox(i18n("Quick loading"), quick_page);
	quick_box->setGeometry(5, 5, 450, 90);

	// Labels
	quick_label_snap = new QLabel(i18n("Quick snapshots:"), quick_box);
	quick_label_prof = new QLabel(i18n("Quick profiles:"), quick_box);
	quick_label_snap->move(5, 17);
	quick_label_prof->move(5, 56);

	// Button group
	quick_group_snap = new QButtonGroup(quick_box);
	quick_group_snap->move(125, 17);
	quick_group_prof = new QButtonGroup(quick_box);
	quick_group_prof->move(125, 56);

	// Buttons
	quick_button_snap_on = new QRadioButton("On", quick_group_snap);
	quick_button_snap_off = new QRadioButton("Off", quick_group_snap);
	quick_button_snap_off->move(50, 0);
	quick_button_prof_on = new QRadioButton("On", quick_group_prof);
	quick_button_prof_off = new QRadioButton("Off", quick_group_prof);
	quick_button_prof_off->move(50, 0);

	// Configure
	quick_group_snap->setButton(!QUICK_SNAP);
	quick_group_prof->setButton(!QUICK_PROF);

	/* Add tabs */
	addTab(main_page, i18n("&General"));
	addTab(quick_page, i18n("&Quick loading"));

	/* Buttons */

	help = new QPushButton( i18n("Help"), this );
	help->setGeometry( 5, 330, 80, 30 );

	setOkButton(i18n("OK"));
	setCancelButton(i18n("Cancel"));

	// Configure and connect
	connect( this, SIGNAL(cancelButtonPressed()), this, SLOT(reject()) );
	connect( this, SIGNAL(applyButtonPressed()), this, SLOT(okPressed()) );
	connect( help, SIGNAL(clicked()), this, SLOT(helpPressed()) );
}

KSnes9xOptionsDialog::~KSnes9xOptionsDialog(){
}










/** Call for help */
void KSnes9xOptionsDialog::helpPressed(){
	kapp->invokeHTMLHelp( 0, 0 );
}

/** Save options and return to the program */
void KSnes9xOptionsDialog::okPressed(){
	FILTER = rom_filter->text();
	PATH = rom_path->text();
	SNAP_FILTER = snap_filter->text();
	SNAP_PATH = snap_path->text();
	SNES9X = snes9x_path->text();

	// Coloca a barra '/' se necessario no PATH e SNAP_PATH
	if (PATH.right(1) != "/")
		PATH += '/';
	if (SNAP_PATH.right(1) != "/")
		SNAP_PATH += '/';

	// Check the QUICK_SNAP and QUICK_PROF
	if (quick_button_snap_on->isChecked())
		QUICK_SNAP = true;
	else
		QUICK_SNAP = false;
	if (quick_button_prof_on->isChecked())
		QUICK_PROF = true;
	else
		QUICK_PROF = false;

}

